# Michigan.Ods.Sdk.Profiles.Rostering.Api.CoursesApi

All URIs are relative to *https://api-mi.doubleline.us:443/ods-int3/data/v3/2023*

Method | HTTP request | Description
------------- | ------------- | -------------
[**GetCourses**](CoursesApi.md#getcourses) | **GET** /ed-fi/courses | Retrieves specific resources using the resource&#39;s property values (using the \&quot;Get\&quot; pattern).
[**GetCoursesById**](CoursesApi.md#getcoursesbyid) | **GET** /ed-fi/courses/{id} | Retrieves a specific resource using the resource&#39;s identifier (using the \&quot;Get By Id\&quot; pattern).


<a name="getcourses"></a>
# **GetCourses**
> List<EdFiCourseReadable> GetCourses (int? offset = null, int? limit = null, int? minChangeVersion = null, int? maxChangeVersion = null, bool? totalCount = null, string courseCode = null, int? educationOrganizationId = null, string academicSubjectDescriptor = null, string careerPathwayDescriptor = null, string courseDefinedByDescriptor = null, string courseGPAApplicabilityDescriptor = null, string courseDescription = null, string courseTitle = null, bool? highSchoolCourseRequirement = null, string id = null, int? numberOfParts = null)

Retrieves specific resources using the resource's property values (using the \"Get\" pattern).

This GET operation provides access to resources using the \"Get\" search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).

### Example
```csharp
using System;
using System.Diagnostics;
using Michigan.Ods.Sdk.Profiles.Rostering.Api;
using Michigan.Ods.Sdk.Client;
using Michigan.Ods.Sdk.Profiles.Rostering.Models;

namespace Example
{
    public class GetCoursesExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new CoursesApi();
            var offset = 56;  // int? | Indicates how many items should be skipped before returning results. (optional)  (default to 0)
            var limit = 56;  // int? | Indicates the maximum number of items that should be returned in the results. (optional)  (default to 25)
            var minChangeVersion = 56;  // int? | Used in synchronization to set sequence minimum ChangeVersion (optional) 
            var maxChangeVersion = 56;  // int? | Used in synchronization to set sequence maximum ChangeVersion (optional) 
            var totalCount = true;  // bool? | Indicates if the total number of items available should be returned in the 'Total-Count' header of the response.  If set to false, 'Total-Count' header will not be provided. (optional)  (default to false)
            var courseCode = courseCode_example;  // string | A unique alphanumeric code assigned to a course. (optional) 
            var educationOrganizationId = 56;  // int? | The identifier assigned to an education organization. (optional) 
            var academicSubjectDescriptor = academicSubjectDescriptor_example;  // string | The intended major subject area of the course. (optional) 
            var careerPathwayDescriptor = careerPathwayDescriptor_example;  // string | Indicates the career cluster or pathway the course is associated with as part of a CTE curriculum. (optional) 
            var courseDefinedByDescriptor = courseDefinedByDescriptor_example;  // string | Specifies whether the course was defined by the SEA, LEA, School, or national organization. (optional) 
            var courseGPAApplicabilityDescriptor = courseGPAApplicabilityDescriptor_example;  // string | An indicator of whether or not the course being described is included in the computation of the student's Grade Point Average, and if so, if it is weighted differently from regular courses. (optional) 
            var courseDescription = courseDescription_example;  // string | A description of the content standards and goals covered in the course. Reference may be made to state or national content standards. (optional) 
            var courseTitle = courseTitle_example;  // string | The descriptive name given to a course of study offered in a school or other institution or organization. In departmentalized classes at the elementary, secondary, and postsecondary levels (and for staff development activities), this refers to the name by which a course is identified (e.g., American History, English III). For elementary and other non-departmentalized classes, it refers to any portion of the instruction for which a grade or report is assigned (e.g., reading, composition, spelling, and language arts). (optional) 
            var highSchoolCourseRequirement = true;  // bool? | An indication that this course may satisfy high school graduation requirements in the course's subject area. (optional) 
            var id = id_example;  // string |  (optional) 
            var numberOfParts = 56;  // int? | The number of parts identified for a course. (optional) 

            try
            {
                // Retrieves specific resources using the resource's property values (using the \"Get\" pattern).
                List&lt;EdFiCourseReadable&gt; result = apiInstance.GetCourses(offset, limit, minChangeVersion, maxChangeVersion, totalCount, courseCode, educationOrganizationId, academicSubjectDescriptor, careerPathwayDescriptor, courseDefinedByDescriptor, courseGPAApplicabilityDescriptor, courseDescription, courseTitle, highSchoolCourseRequirement, id, numberOfParts);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling CoursesApi.GetCourses: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **offset** | **int?**| Indicates how many items should be skipped before returning results. | [optional] [default to 0]
 **limit** | **int?**| Indicates the maximum number of items that should be returned in the results. | [optional] [default to 25]
 **minChangeVersion** | **int?**| Used in synchronization to set sequence minimum ChangeVersion | [optional] 
 **maxChangeVersion** | **int?**| Used in synchronization to set sequence maximum ChangeVersion | [optional] 
 **totalCount** | **bool?**| Indicates if the total number of items available should be returned in the &#39;Total-Count&#39; header of the response.  If set to false, &#39;Total-Count&#39; header will not be provided. | [optional] [default to false]
 **courseCode** | **string**| A unique alphanumeric code assigned to a course. | [optional] 
 **educationOrganizationId** | **int?**| The identifier assigned to an education organization. | [optional] 
 **academicSubjectDescriptor** | **string**| The intended major subject area of the course. | [optional] 
 **careerPathwayDescriptor** | **string**| Indicates the career cluster or pathway the course is associated with as part of a CTE curriculum. | [optional] 
 **courseDefinedByDescriptor** | **string**| Specifies whether the course was defined by the SEA, LEA, School, or national organization. | [optional] 
 **courseGPAApplicabilityDescriptor** | **string**| An indicator of whether or not the course being described is included in the computation of the student&#39;s Grade Point Average, and if so, if it is weighted differently from regular courses. | [optional] 
 **courseDescription** | **string**| A description of the content standards and goals covered in the course. Reference may be made to state or national content standards. | [optional] 
 **courseTitle** | **string**| The descriptive name given to a course of study offered in a school or other institution or organization. In departmentalized classes at the elementary, secondary, and postsecondary levels (and for staff development activities), this refers to the name by which a course is identified (e.g., American History, English III). For elementary and other non-departmentalized classes, it refers to any portion of the instruction for which a grade or report is assigned (e.g., reading, composition, spelling, and language arts). | [optional] 
 **highSchoolCourseRequirement** | **bool?**| An indication that this course may satisfy high school graduation requirements in the course&#39;s subject area. | [optional] 
 **id** | **string**|  | [optional] 
 **numberOfParts** | **int?**| The number of parts identified for a course. | [optional] 

### Return type

[**List<EdFiCourseReadable>**](EdFiCourseReadable.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/vnd.ed-fi.course.rostering.readable+json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

<a name="getcoursesbyid"></a>
# **GetCoursesById**
> EdFiCourseReadable GetCoursesById (string id, string ifNoneMatch = null)

Retrieves a specific resource using the resource's identifier (using the \"Get By Id\" pattern).

This GET operation retrieves a resource by the specified resource identifier.

### Example
```csharp
using System;
using System.Diagnostics;
using Michigan.Ods.Sdk.Profiles.Rostering.Api;
using Michigan.Ods.Sdk.Client;
using Michigan.Ods.Sdk.Profiles.Rostering.Models;

namespace Example
{
    public class GetCoursesByIdExample
    {
        public void main()
        {
            // Configure OAuth2 access token for authorization: oauth2_client_credentials
            Configuration.Default.AccessToken = "YOUR_ACCESS_TOKEN";

            var apiInstance = new CoursesApi();
            var id = id_example;  // string | A resource identifier that uniquely identifies the resource.
            var ifNoneMatch = ifNoneMatch_example;  // string | The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource. (optional) 

            try
            {
                // Retrieves a specific resource using the resource's identifier (using the \"Get By Id\" pattern).
                EdFiCourseReadable result = apiInstance.GetCoursesById(id, ifNoneMatch);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling CoursesApi.GetCoursesById: " + e.Message );
            }
        }
    }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **string**| A resource identifier that uniquely identifies the resource. | 
 **ifNoneMatch** | **string**| The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource. | [optional] 

### Return type

[**EdFiCourseReadable**](EdFiCourseReadable.md)

### Authorization

[oauth2_client_credentials](../README.md#oauth2_client_credentials)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/vnd.ed-fi.course.rostering.readable+json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

